Struct Graphemes

struct Graphemes<'a> { ... }

External iterator for a string's grapheme clusters.

This struct is created by the graphemes method on the UnicodeSegmentation trait. See its documentation for more.

Implementations

impl<'a> Graphemes<'a>

fn as_str(self: &Self) -> &'a str

View the underlying data (the part yet to be iterated) as a slice of the original string.

# use unicode_segmentation::UnicodeSegmentation;
let mut iter = "abc".graphemes(true);
assert_eq!(iter.as_str(), "abc");
iter.next();
assert_eq!(iter.as_str(), "bc");
iter.next();
iter.next();
assert_eq!(iter.as_str(), "");

impl<'a> Clone for Graphemes<'a>

fn clone(self: &Self) -> Graphemes<'a>

impl<'a> Debug for Graphemes<'a>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a> DoubleEndedIterator for Graphemes<'a>

fn next_back(self: &mut Self) -> Option<&'a str>

impl<'a> Freeze for Graphemes<'a>

impl<'a> Iterator for Graphemes<'a>

fn size_hint(self: &Self) -> (usize, Option<usize>)
fn next(self: &mut Self) -> Option<&'a str>

impl<'a> RefUnwindSafe for Graphemes<'a>

impl<'a> Send for Graphemes<'a>

impl<'a> Sync for Graphemes<'a>

impl<'a> Unpin for Graphemes<'a>

impl<'a> UnsafeUnpin for Graphemes<'a>

impl<'a> UnwindSafe for Graphemes<'a>

impl<I> IntoIterator for Graphemes<'a>

fn into_iter(self: Self) -> I

impl<T> Any for Graphemes<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Graphemes<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Graphemes<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Graphemes<'a>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Graphemes<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Graphemes<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Graphemes<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Graphemes<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>