Struct UnicodeWordIndices
struct UnicodeWordIndices<'a> { ... }
An iterator over the substrings of a string which, after splitting the string on word boundaries, contain any characters with the Alphabetic property, or with General_Category=Number. This iterator also provides the byte offsets for each substring.
This struct is created by the unicode_word_indices method on the UnicodeSegmentation trait. See
its documentation for more.
Implementations
impl<'a> Debug for UnicodeWordIndices<'a>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a> DoubleEndedIterator for UnicodeWordIndices<'a>
fn next_back(self: &mut Self) -> Option<(usize, &'a str)>
impl<'a> Freeze for UnicodeWordIndices<'a>
impl<'a> Iterator for UnicodeWordIndices<'a>
fn next(self: &mut Self) -> Option<(usize, &'a str)>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<'a> RefUnwindSafe for UnicodeWordIndices<'a>
impl<'a> Send for UnicodeWordIndices<'a>
impl<'a> Sync for UnicodeWordIndices<'a>
impl<'a> Unpin for UnicodeWordIndices<'a>
impl<'a> UnsafeUnpin for UnicodeWordIndices<'a>
impl<'a> UnwindSafe for UnicodeWordIndices<'a>
impl<I> IntoIterator for UnicodeWordIndices<'a>
fn into_iter(self: Self) -> I
impl<T> Any for UnicodeWordIndices<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for UnicodeWordIndices<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for UnicodeWordIndices<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for UnicodeWordIndices<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for UnicodeWordIndices<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for UnicodeWordIndices<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for UnicodeWordIndices<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>