Enum GraphemeIncomplete
enum GraphemeIncomplete
An error return indicating that not enough content was available in the provided chunk to satisfy the query, and that more content must be provided.
Variants
-
PreContext(usize) More pre-context is needed. The caller should call
provide_contextwith a chunk ending at the offset given, then retry the query. This will only be returned if thechunk_startparameter is nonzero.-
PrevChunk When requesting
prev_boundary, the cursor is moving past the beginning of the current chunk, so the chunk before that is requested. This will only be returned if thechunk_startparameter is nonzero.-
NextChunk When requesting
next_boundary, the cursor is moving past the end of the current chunk, so the chunk after that is requested. This will only be returned if the chunk ends before thelenparameter provided on creation of the cursor.-
InvalidOffset An error returned when the chunk given does not contain the cursor position.
Implementations
impl Debug for GraphemeIncomplete
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for GraphemeIncomplete
impl Freeze for GraphemeIncomplete
impl PartialEq for GraphemeIncomplete
fn eq(self: &Self, other: &GraphemeIncomplete) -> bool
impl RefUnwindSafe for GraphemeIncomplete
impl Send for GraphemeIncomplete
impl StructuralPartialEq for GraphemeIncomplete
impl Sync for GraphemeIncomplete
impl Unpin for GraphemeIncomplete
impl UnsafeUnpin for GraphemeIncomplete
impl UnwindSafe for GraphemeIncomplete
impl<T> Any for GraphemeIncomplete
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for GraphemeIncomplete
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for GraphemeIncomplete
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for GraphemeIncomplete
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for GraphemeIncomplete
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for GraphemeIncomplete
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for GraphemeIncomplete
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>